OpenTuiFfiType enum
Values
- voidType → const OpenTuiFfiType
- pointer → const OpenTuiFfiType
- boolType → const OpenTuiFfiType
- i32 → const OpenTuiFfiType
- i64 → const OpenTuiFfiType
- u8 → const OpenTuiFfiType
- u16 → const OpenTuiFfiType
- u32 → const OpenTuiFfiType
- u64 → const OpenTuiFfiType
- usize → const OpenTuiFfiType
- f32 → const OpenTuiFfiType
- f64 → const OpenTuiFfiType
- unknown → const OpenTuiFfiType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OpenTuiFfiType> - A constant List of the values in this enum, in order of their declaration.