OpenTuiRawBindings class final

Annotations
  • @experimental

Constructors

OpenTuiRawBindings(DynamicLibrary dynamicLibrary)

Properties

dynamicLibrary DynamicLibrary
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasSymbol(String symbol) bool
loadedSymbols() Set<String>
lookupRawPointer(String symbol) Pointer<NativeType>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited